% This plots the equalization MSE surface for DALE and returns a handle to it 

function h_contours = msesurf_eq(C,lambda,gamma,Rii,h_des,f_des,ranges,cur_fig_num)
 
 % check if two-tap
 if length(f_des) ~= 2, 
   error('surface plots only for equalizer lengths of 2'); 
 end;

 % define a grid in f space 
 num_pts = 20;				% <80 seems to work well
 f0_grid = linspace(f_des(1)-ranges(1),f_des(1)+ranges(1),num_pts);
 f1_grid = linspace(f_des(2)-ranges(2),f_des(2)+ranges(2),num_pts);
 L0 = length(f0_grid); L1 = length(f1_grid);

 %%%%%%%%%%%% PLOT THE STUFF %%%%%%%%%%%%%

 MSE = zeros(L0,L1);
 for i=1:L0,
   for k=1:L1,
     MSE(i,k) = norm(h_des - C*[f0_grid(i);f1_grid(k)])^2 ...
     	 + lambda*[f0_grid(i);f1_grid(k)]'*[f0_grid(i);f1_grid(k)]...
	 + gamma*[f0_grid(i);f1_grid(k)]'*Rii*[f0_grid(i);f1_grid(k)];
   end
 end

 % plot MSE contours 
 figure(cur_fig_num);
 [dum,h_contours] = contour(f0_grid,f1_grid,MSE',20,'c'); 
 hold on; h_contours = [h_contours.',plot(f_des(1),f_des(2),'x')]; hold off;
 xlabel('f0'); ylabel('f1');
 axis([f_des(1)-ranges(1),f_des(1)+ranges(1),...
       f_des(2)-ranges(2),f_des(2)+ranges(2)]);		% needed if hold is on
 grid off;
 title('MSE Surface');

