% this reads ui and sets global parameters for DALE

 % key parameters already obtained: is_FSE, N_f, c, N_c

 % get trace color
 ui_color;

 % get remaining channel params
 SNR = str2num(get(h_SNR,'String'));
 if (~isreal(SNR))|(max(size(SNR)) ~= 1),
   error('SNR must be a real-valued scalar or "Inf"');
 elseif SNR == Inf, 
   SNR = 10000; 
 end
 SIR = str2num(get(h_SIR,'String'));
 if (~isreal(SIR))|(max(size(SIR)) ~= 1),
   error('SIR must be a real-valued scalar or "Inf"');
 elseif SIR == Inf, 
   SIR = 10000; 
 end

 % process the channel parameters
 CC = convmtx(c,N_f);		% channel convolution matrix
 if is_FSE,
   C = CC(2:2:N_c+N_f-1,:);     % odd-sampled decimated FS chan conv matrix
 else
   C = CC;                      % keep BS chan conv matrix
 end
 N_h = length(C(:,1));
 sigma2_n = 10^(-SNR/10);
 sigma2_i = 10^(-SIR/10);
 lambda = sigma2_n;		% noise power: assumes sigma2_s = 1
 gamma = sigma2_i;		% interferer power: assumes sigma2_s = 1
 f_i = 0.25;			% baud-normalized interferer freq (0 < w < 0.5)
 Rii = toeplitz(cos(2*pi*f_i/(1+is_FSE)*[0:N_f-1])); % interferer autocov mtx
 Rxx = C'*C+lambda*eye(N_f)+gamma*Rii;	  % regressor autocovariance matrix
 P = pinv(Rxx);
 E = eye(N_h) - C*P*C'; 	% mse scaled correctly if sigma2_s = 1
 [mse_opt,delta_opt] = min(diag(E));	
 F = P*C';			% equalizers

 % eigenanalysis (with protection for singular channel case)
 [V,Lam] = eig(Rxx);
 vec1 = V(:,1)*sqrt(1./max(Lam(1,1),eps));	% (scaled) ellipse axis
 vec2 = V(:,2)*sqrt(1./max(Lam(2,2),eps));	% (scaled) ellipse axis

 % update delay widget
 delay_string = [];
 for i=1:N_h-1,
   delay_string = [delay_string,num2str(i-delta_opt),'|'];
 end
 delay_string = [delay_string,num2str(N_h-delta_opt)];
 if strcmp(get(h_delay,'String'),'0'),		% first time around
   delay_offset = 0;
   set(h_delay, 'String',delay_string);
   set(h_delay, 'Value',delta_opt+delay_offset);
 else						% been here before 
   if delta_opt+delay_offset<1
     delay_offset = 1-delta_opt;		% invalid delay: reset to min 
   elseif delta_opt+delay_offset>N_h
     delay_offset = N_h-delta_opt;		% invalid delay: reset to max 
   end
   set(h_delay, 'String',delay_string);
   set(h_delay, 'Value',delta_opt+delay_offset);
 end

 % calculate desired mse (i.e. optimal for chosen delay)
 mse_des = E(delta_opt+delay_offset,delta_opt+delay_offset);

 % remember old surface parameters 
 if exist('f_des')&exist('ranges'),
   f_des_old = f_des;
   ranges_old = ranges;
 else
   f_des_old = NaN*ones(N_f,1);
   ranges_old = [NaN,NaN];
 end

 % determine origin and range of equalizer surface 
 h_des = zeros(N_h,1); h_des(delta_opt+delay_offset)=1;
 f_des = F*h_des;				% origin
 ranges = max(abs([vec1,vec2].')).';		% range

 % see if the channel or equalizer has changed significantly
 has_changed = 0;
 if (N_f ~= length(f_des_old)),
   has_changed = 1;
 elseif (f_des ~= f_des_old)|(ranges ~= ranges_old),
   has_changed = 1;
 end

 % clear {eigenstuff,surface,mse-bound,trajectories} if needed 
 if has_changed,
   set(h_sprd,'String','');
   if ishandle(h_trace_g), delete(h_trace_g); end; h_trace_g = [];
   if ishandle(h_trace_c), delete(h_trace_c); end; h_trace_c = [];
   if ishandle(h_trace_mse), delete(h_trace_mse); end; h_trace_mse = [];
   if ishandle(h_trace_t), delete(h_trace_t); end; h_trace_t = [];
   for i=1:length(h_trace_ff),
     if ishandle(h_trace_ff(i)), delete(h_trace_ff(i)); end;
   end
   h_trace_ff = [];
 end
